aboutsummaryrefslogtreecommitdiffstats
path: root/Rpmdrake/pkg.pm
diff options
context:
space:
mode:
Diffstat (limited to 'Rpmdrake/pkg.pm')
-rw-r--r--Rpmdrake/pkg.pm10
1 files changed, 5 insertions, 5 deletions
diff --git a/Rpmdrake/pkg.pm b/Rpmdrake/pkg.pm
index a2f3e4d6..dbfb4e1c 100644
--- a/Rpmdrake/pkg.pm
+++ b/Rpmdrake/pkg.pm
@@ -21,7 +21,7 @@ package Rpmdrake::pkg;
#
#*****************************************************************************
#
-# $Id$
+# $Id: pkg.pm 270160 2010-06-22 19:55:40Z jvictor $
use strict;
use MDK::Common::Func 'any';
@@ -255,8 +255,8 @@ Then, restart \"%s\".", N("Enabled"), $rpmdrake::myname_update));
}
my ($mirror) = choose_mirror($urpm, transient => $w->{real_window} || $::main_window,
message => join("\n\n",
- N("You have no configured update media. MandrivaUpdate cannot operate without any update media."),
- N("I need to contact the Mandriva website to get the mirror list.
+ N("You have no configured update media. MageiaUpdate cannot operate without any update media."),
+ N("I need to contact the Mageia website to get the mirror list.
Please check that your network is currently running.
Is it ok to continue?"),
@@ -405,7 +405,7 @@ sub get_updates_list {
@$requested_list = ();
}
# list updates including skiped ones + their deps in MandrivaUpdate:
@$requested_list = uniq(@$requested_list, @$requested_strict);
# do not pre select updates in rpmdrake:
@@ -529,7 +529,7 @@ sub get_pkgs {
}
}
@updates = @requested;
# selecting updates by default but skipped ones (MandrivaUpdate only):
foreach (@requested_strict) {
$all_pkgs{$_}{selected} = 1;
}
@@ -405,7 +405,7 @@ sub get_updates_list {
}
- # list updates including skiped ones + their deps in MandrivaUpdate:
+ # list updates including skiped ones + their deps in MageiaUpdate:
# do not pre select updates in rpmdrake:
@@ -529,7 +529,7 @@ sub get_pkgs {
}
- # selecting updates by default but skipped ones (MandrivaUpdate only):
+ # selecting updates by default but skipped ones (MageiaUpdate only):
foreach (@requested_strict) {
$all_pkgs{$_}{selected} = 1;